@@ -79,6 +79,7 @@ class SqlQueue(object):
         self.sqlq = None
         self.sqlq_worker = None
         self.functions = None
+        self.sc = None
         if self.is_server:
             if not os.path.isabs(db):
                 db = join_path(abs_cwd(depth=2), db)
@@ -88,6 +89,8 @@ class SqlQueue(object):
             self.sqlq_worker.daemon = True
             self.sqlq_worker.start()
             self.functions = dict(sql=self.sql)
+        else:
+            self.sc = SC()
 
     def _sql(self, tid: int, sql: str, data: tuple = ()) -> list:
         if self.is_server:
@@ -100,7 +103,7 @@ class SqlQueue(object):
             finally:
                 self.exc_result.pop(tid)
         else:
-            return SC().request(command="sql", data=(sql, data))
+            return self.sc.request(command="sql", data=(sql, data))
 
     def sql(self, sql: str, data: tuple = (), result: Any = None, key: Any = None) -> list:
         if result is None:
